# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: info.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import consensus_pb2 as consensus__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='info.proto',
  package='io.casperlabs.casper.consensus.info',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\ninfo.proto\x12#io.casperlabs.casper.consensus.info\x1a\x0f\x63onsensus.proto\"\xf8\x02\n\tBlockInfo\x12=\n\x07summary\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.BlockSummary\x12\x45\n\x06status\x18\x02 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.info.BlockInfo.Status\x1a\xc7\x01\n\x06Status\x12\x17\n\x0f\x66\x61ult_tolerance\x18\x01 \x01(\x02\x12J\n\x05stats\x18\x02 \x01(\x0b\x32;.io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats\x1aX\n\x05Stats\x12\x18\n\x10\x62lock_size_bytes\x18\x01 \x01(\r\x12\x1a\n\x12\x64\x65ploy_error_count\x18\x02 \x01(\r\x12\x19\n\x11\x64\x65ploy_cost_total\x18\x03 \x01(\x04\"\x1b\n\x04View\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\"\xca\x04\n\nDeployInfo\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\x12\\\n\x12processing_results\x18\x02 \x03(\x0b\x32@.io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32\x36.io.casperlabs.casper.consensus.info.DeployInfo.Status\x1a\x8d\x01\n\x10ProcessingResult\x12\x42\n\nblock_info\x18\x01 \x01(\x0b\x32..io.casperlabs.casper.consensus.info.BlockInfo\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x04\x12\x10\n\x08is_error\x18\x03 \x01(\x08\x12\x15\n\rerror_message\x18\x04 \x01(\t\x1a_\n\x06Status\x12\x44\n\x05state\x18\x01 \x01(\x0e\x32\x35.io.casperlabs.casper.consensus.info.DeployInfo.State\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1b\n\x04View\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\"P\n\x05State\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tPROCESSED\x10\x02\x12\r\n\tFINALIZED\x10\x03\x12\r\n\tDISCARDED\x10\x04\x62\x06proto3')
  ,
  dependencies=[consensus__pb2.DESCRIPTOR,])



_BLOCKINFO_VIEW = _descriptor.EnumDescriptor(
  name='View',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo.View',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=418,
  serialized_end=445,
)
_sym_db.RegisterEnumDescriptor(_BLOCKINFO_VIEW)

_DEPLOYINFO_VIEW = _descriptor.EnumDescriptor(
  name='View',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.View',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=418,
  serialized_end=445,
)
_sym_db.RegisterEnumDescriptor(_DEPLOYINFO_VIEW)

_DEPLOYINFO_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINALIZED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISCARDED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=954,
  serialized_end=1034,
)
_sym_db.RegisterEnumDescriptor(_DEPLOYINFO_STATE)


_BLOCKINFO_STATUS_STATS = _descriptor.Descriptor(
  name='Stats',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_size_bytes', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats.block_size_bytes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_error_count', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats.deploy_error_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deploy_cost_total', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats.deploy_cost_total', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=416,
)

_BLOCKINFO_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fault_tolerance', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.fault_tolerance', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='io.casperlabs.casper.consensus.info.BlockInfo.Status.stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BLOCKINFO_STATUS_STATS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=416,
)

_BLOCKINFO = _descriptor.Descriptor(
  name='BlockInfo',
  full_name='io.casperlabs.casper.consensus.info.BlockInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary', full_name='io.casperlabs.casper.consensus.info.BlockInfo.summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='io.casperlabs.casper.consensus.info.BlockInfo.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BLOCKINFO_STATUS, ],
  enum_types=[
    _BLOCKINFO_VIEW,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=445,
)


_DEPLOYINFO_PROCESSINGRESULT = _descriptor.Descriptor(
  name='ProcessingResult',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_info', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.block_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cost', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.cost', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_error', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.is_error', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult.error_message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=826,
)

_DEPLOYINFO_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo.Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='io.casperlabs.casper.consensus.info.DeployInfo.Status.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.casper.consensus.info.DeployInfo.Status.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=923,
)

_DEPLOYINFO = _descriptor.Descriptor(
  name='DeployInfo',
  full_name='io.casperlabs.casper.consensus.info.DeployInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.casper.consensus.info.DeployInfo.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processing_results', full_name='io.casperlabs.casper.consensus.info.DeployInfo.processing_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='io.casperlabs.casper.consensus.info.DeployInfo.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOYINFO_PROCESSINGRESULT, _DEPLOYINFO_STATUS, ],
  enum_types=[
    _DEPLOYINFO_VIEW,
    _DEPLOYINFO_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=1034,
)

_BLOCKINFO_STATUS_STATS.containing_type = _BLOCKINFO_STATUS
_BLOCKINFO_STATUS.fields_by_name['stats'].message_type = _BLOCKINFO_STATUS_STATS
_BLOCKINFO_STATUS.containing_type = _BLOCKINFO
_BLOCKINFO.fields_by_name['summary'].message_type = consensus__pb2._BLOCKSUMMARY
_BLOCKINFO.fields_by_name['status'].message_type = _BLOCKINFO_STATUS
_BLOCKINFO_VIEW.containing_type = _BLOCKINFO
_DEPLOYINFO_PROCESSINGRESULT.fields_by_name['block_info'].message_type = _BLOCKINFO
_DEPLOYINFO_PROCESSINGRESULT.containing_type = _DEPLOYINFO
_DEPLOYINFO_STATUS.fields_by_name['state'].enum_type = _DEPLOYINFO_STATE
_DEPLOYINFO_STATUS.containing_type = _DEPLOYINFO
_DEPLOYINFO.fields_by_name['deploy'].message_type = consensus__pb2._DEPLOY
_DEPLOYINFO.fields_by_name['processing_results'].message_type = _DEPLOYINFO_PROCESSINGRESULT
_DEPLOYINFO.fields_by_name['status'].message_type = _DEPLOYINFO_STATUS
_DEPLOYINFO_VIEW.containing_type = _DEPLOYINFO
_DEPLOYINFO_STATE.containing_type = _DEPLOYINFO
DESCRIPTOR.message_types_by_name['BlockInfo'] = _BLOCKINFO
DESCRIPTOR.message_types_by_name['DeployInfo'] = _DEPLOYINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockInfo = _reflection.GeneratedProtocolMessageType('BlockInfo', (_message.Message,), {

  'Status' : _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {

    'Stats' : _reflection.GeneratedProtocolMessageType('Stats', (_message.Message,), {
      'DESCRIPTOR' : _BLOCKINFO_STATUS_STATS,
      '__module__' : 'info_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.BlockInfo.Status.Stats)
      })
    ,
    'DESCRIPTOR' : _BLOCKINFO_STATUS,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.BlockInfo.Status)
    })
  ,
  'DESCRIPTOR' : _BLOCKINFO,
  '__module__' : 'info_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.BlockInfo)
  })
_sym_db.RegisterMessage(BlockInfo)
_sym_db.RegisterMessage(BlockInfo.Status)
_sym_db.RegisterMessage(BlockInfo.Status.Stats)

DeployInfo = _reflection.GeneratedProtocolMessageType('DeployInfo', (_message.Message,), {

  'ProcessingResult' : _reflection.GeneratedProtocolMessageType('ProcessingResult', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYINFO_PROCESSINGRESULT,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.DeployInfo.ProcessingResult)
    })
  ,

  'Status' : _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYINFO_STATUS,
    '__module__' : 'info_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.DeployInfo.Status)
    })
  ,
  'DESCRIPTOR' : _DEPLOYINFO,
  '__module__' : 'info_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.info.DeployInfo)
  })
_sym_db.RegisterMessage(DeployInfo)
_sym_db.RegisterMessage(DeployInfo.ProcessingResult)
_sym_db.RegisterMessage(DeployInfo.Status)


# @@protoc_insertion_point(module_scope)
