# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: diagnostics.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import empty_pb2 as empty__pb2
from . import wrappers_pb2 as wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='diagnostics.proto',
  package='io.casperlabs.node.api.diagnostics',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x11\x64iagnostics.proto\x12\"io.casperlabs.node.api.diagnostics\x1a\x0b\x65mpty.proto\x1a\x0ewrappers.proto\"c\n\nProcessCpu\x12*\n\x04load\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12)\n\x04time\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x84\x01\n\x0bMemoryUsage\x12\x38\n\x04heap\x18\x01 \x01(\x0b\x32*.io.casperlabs.node.api.diagnostics.Memory\x12;\n\x07nonHeap\x18\x02 \x01(\x0b\x32*.io.casperlabs.node.api.diagnostics.Memory\"a\n\x06Memory\x12\x11\n\tcommitted\x18\x01 \x01(\x03\x12\x0c\n\x04init\x18\x02 \x01(\x03\x12(\n\x03max\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x0c\n\x04used\x18\x04 \x01(\x03\"\xe4\x01\n\x10GarbageCollector\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10totalCollections\x18\x02 \x01(\x03\x12\x1b\n\x13totalCollectionTime\x18\x03 \x01(\x03\x12.\n\tstartTime\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12,\n\x07\x65ndTime\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12-\n\x08\x64uration\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xa6\x01\n\nMemoryPool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08poolType\x18\x02 \x01(\t\x12\x39\n\x05usage\x18\x03 \x01(\x0b\x32*.io.casperlabs.node.api.diagnostics.Memory\x12=\n\tpeakUsage\x18\x04 \x01(\x0b\x32*.io.casperlabs.node.api.diagnostics.Memory\"s\n\x07Threads\x12\x13\n\x0bthreadCount\x18\x01 \x01(\x05\x12\x19\n\x11\x64\x61\x65monThreadCount\x18\x02 \x01(\x05\x12\x17\n\x0fpeakThreadCount\x18\x03 \x01(\x05\x12\x1f\n\x17totalStartedThreadCount\x18\x04 \x01(\x03\"\xfd\x01\n\x0fNodeCoreMetrics\x12\x19\n\x11pingReceiverCount\x18\x01 \x01(\x03\x12\x1b\n\x13lookupReceiverCount\x18\x02 \x01(\x03\x12\x1f\n\x17\x64isconnectReceiverCount\x18\x03 \x01(\x03\x12\x10\n\x08\x63onnects\x18\x04 \x01(\x03\x12+\n#p2pEncryptionHandshakeReceiverCount\x18\x05 \x01(\x03\x12)\n!p2pProtocolHandshakeReceiverCount\x18\x06 \x01(\x03\x12\r\n\x05peers\x18\x07 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x08 \x01(\x03\x12\n\n\x02to\x18\t \x01(\x03\"d\n\x11GarbageCollectors\x12O\n\x11garbageCollectors\x18\x01 \x03(\x0b\x32\x34.io.casperlabs.node.api.diagnostics.GarbageCollector\"R\n\x0bMemoryPools\x12\x43\n\x0bmemoryPools\x18\x01 \x03(\x0b\x32..io.casperlabs.node.api.diagnostics.MemoryPool\"@\n\x05Peers\x12\x37\n\x05peers\x18\x01 \x03(\x0b\x32(.io.casperlabs.node.api.diagnostics.Peer\"/\n\x04Peer\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x32\xe3\x05\n\x0b\x44iagnostics\x12N\n\tListPeers\x12\x16.google.protobuf.Empty\x1a).io.casperlabs.node.api.diagnostics.Peers\x12X\n\x13ListDiscoveredPeers\x12\x16.google.protobuf.Empty\x1a).io.casperlabs.node.api.diagnostics.Peers\x12W\n\rGetProcessCpu\x12\x16.google.protobuf.Empty\x1a..io.casperlabs.node.api.diagnostics.ProcessCpu\x12Y\n\x0eGetMemoryUsage\x12\x16.google.protobuf.Empty\x1a/.io.casperlabs.node.api.diagnostics.MemoryUsage\x12\x65\n\x14GetGarbageCollectors\x12\x16.google.protobuf.Empty\x1a\x35.io.casperlabs.node.api.diagnostics.GarbageCollectors\x12Y\n\x0eGetMemoryPools\x12\x16.google.protobuf.Empty\x1a/.io.casperlabs.node.api.diagnostics.MemoryPools\x12Q\n\nGetThreads\x12\x16.google.protobuf.Empty\x1a+.io.casperlabs.node.api.diagnostics.Threads\x12\x61\n\x12GetNodeCoreMetrics\x12\x16.google.protobuf.Empty\x1a\x33.io.casperlabs.node.api.diagnostics.NodeCoreMetricsb\x06proto3')
  ,
  dependencies=[empty__pb2.DESCRIPTOR,wrappers__pb2.DESCRIPTOR,])




_PROCESSCPU = _descriptor.Descriptor(
  name='ProcessCpu',
  full_name='io.casperlabs.node.api.diagnostics.ProcessCpu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='load', full_name='io.casperlabs.node.api.diagnostics.ProcessCpu.load', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='io.casperlabs.node.api.diagnostics.ProcessCpu.time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=185,
)


_MEMORYUSAGE = _descriptor.Descriptor(
  name='MemoryUsage',
  full_name='io.casperlabs.node.api.diagnostics.MemoryUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heap', full_name='io.casperlabs.node.api.diagnostics.MemoryUsage.heap', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nonHeap', full_name='io.casperlabs.node.api.diagnostics.MemoryUsage.nonHeap', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=320,
)


_MEMORY = _descriptor.Descriptor(
  name='Memory',
  full_name='io.casperlabs.node.api.diagnostics.Memory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='committed', full_name='io.casperlabs.node.api.diagnostics.Memory.committed', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='init', full_name='io.casperlabs.node.api.diagnostics.Memory.init', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='io.casperlabs.node.api.diagnostics.Memory.max', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='used', full_name='io.casperlabs.node.api.diagnostics.Memory.used', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=419,
)


_GARBAGECOLLECTOR = _descriptor.Descriptor(
  name='GarbageCollector',
  full_name='io.casperlabs.node.api.diagnostics.GarbageCollector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.node.api.diagnostics.GarbageCollector.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalCollections', full_name='io.casperlabs.node.api.diagnostics.GarbageCollector.totalCollections', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalCollectionTime', full_name='io.casperlabs.node.api.diagnostics.GarbageCollector.totalCollectionTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='io.casperlabs.node.api.diagnostics.GarbageCollector.startTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='io.casperlabs.node.api.diagnostics.GarbageCollector.endTime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='io.casperlabs.node.api.diagnostics.GarbageCollector.duration', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=422,
  serialized_end=650,
)


_MEMORYPOOL = _descriptor.Descriptor(
  name='MemoryPool',
  full_name='io.casperlabs.node.api.diagnostics.MemoryPool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.node.api.diagnostics.MemoryPool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poolType', full_name='io.casperlabs.node.api.diagnostics.MemoryPool.poolType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usage', full_name='io.casperlabs.node.api.diagnostics.MemoryPool.usage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peakUsage', full_name='io.casperlabs.node.api.diagnostics.MemoryPool.peakUsage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=819,
)


_THREADS = _descriptor.Descriptor(
  name='Threads',
  full_name='io.casperlabs.node.api.diagnostics.Threads',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threadCount', full_name='io.casperlabs.node.api.diagnostics.Threads.threadCount', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daemonThreadCount', full_name='io.casperlabs.node.api.diagnostics.Threads.daemonThreadCount', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peakThreadCount', full_name='io.casperlabs.node.api.diagnostics.Threads.peakThreadCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalStartedThreadCount', full_name='io.casperlabs.node.api.diagnostics.Threads.totalStartedThreadCount', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=936,
)


_NODECOREMETRICS = _descriptor.Descriptor(
  name='NodeCoreMetrics',
  full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pingReceiverCount', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.pingReceiverCount', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lookupReceiverCount', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.lookupReceiverCount', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disconnectReceiverCount', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.disconnectReceiverCount', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connects', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.connects', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2pEncryptionHandshakeReceiverCount', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.p2pEncryptionHandshakeReceiverCount', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='p2pProtocolHandshakeReceiverCount', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.p2pProtocolHandshakeReceiverCount', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peers', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.peers', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.from', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='io.casperlabs.node.api.diagnostics.NodeCoreMetrics.to', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=1192,
)


_GARBAGECOLLECTORS = _descriptor.Descriptor(
  name='GarbageCollectors',
  full_name='io.casperlabs.node.api.diagnostics.GarbageCollectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='garbageCollectors', full_name='io.casperlabs.node.api.diagnostics.GarbageCollectors.garbageCollectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1294,
)


_MEMORYPOOLS = _descriptor.Descriptor(
  name='MemoryPools',
  full_name='io.casperlabs.node.api.diagnostics.MemoryPools',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memoryPools', full_name='io.casperlabs.node.api.diagnostics.MemoryPools.memoryPools', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1296,
  serialized_end=1378,
)


_PEERS = _descriptor.Descriptor(
  name='Peers',
  full_name='io.casperlabs.node.api.diagnostics.Peers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='io.casperlabs.node.api.diagnostics.Peers.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1380,
  serialized_end=1444,
)


_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='io.casperlabs.node.api.diagnostics.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='io.casperlabs.node.api.diagnostics.Peer.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='io.casperlabs.node.api.diagnostics.Peer.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.node.api.diagnostics.Peer.key', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1493,
)

_PROCESSCPU.fields_by_name['load'].message_type = wrappers__pb2._DOUBLEVALUE
_PROCESSCPU.fields_by_name['time'].message_type = wrappers__pb2._INT64VALUE
_MEMORYUSAGE.fields_by_name['heap'].message_type = _MEMORY
_MEMORYUSAGE.fields_by_name['nonHeap'].message_type = _MEMORY
_MEMORY.fields_by_name['max'].message_type = wrappers__pb2._INT64VALUE
_GARBAGECOLLECTOR.fields_by_name['startTime'].message_type = wrappers__pb2._INT64VALUE
_GARBAGECOLLECTOR.fields_by_name['endTime'].message_type = wrappers__pb2._INT64VALUE
_GARBAGECOLLECTOR.fields_by_name['duration'].message_type = wrappers__pb2._INT64VALUE
_MEMORYPOOL.fields_by_name['usage'].message_type = _MEMORY
_MEMORYPOOL.fields_by_name['peakUsage'].message_type = _MEMORY
_GARBAGECOLLECTORS.fields_by_name['garbageCollectors'].message_type = _GARBAGECOLLECTOR
_MEMORYPOOLS.fields_by_name['memoryPools'].message_type = _MEMORYPOOL
_PEERS.fields_by_name['peers'].message_type = _PEER
DESCRIPTOR.message_types_by_name['ProcessCpu'] = _PROCESSCPU
DESCRIPTOR.message_types_by_name['MemoryUsage'] = _MEMORYUSAGE
DESCRIPTOR.message_types_by_name['Memory'] = _MEMORY
DESCRIPTOR.message_types_by_name['GarbageCollector'] = _GARBAGECOLLECTOR
DESCRIPTOR.message_types_by_name['MemoryPool'] = _MEMORYPOOL
DESCRIPTOR.message_types_by_name['Threads'] = _THREADS
DESCRIPTOR.message_types_by_name['NodeCoreMetrics'] = _NODECOREMETRICS
DESCRIPTOR.message_types_by_name['GarbageCollectors'] = _GARBAGECOLLECTORS
DESCRIPTOR.message_types_by_name['MemoryPools'] = _MEMORYPOOLS
DESCRIPTOR.message_types_by_name['Peers'] = _PEERS
DESCRIPTOR.message_types_by_name['Peer'] = _PEER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessCpu = _reflection.GeneratedProtocolMessageType('ProcessCpu', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSCPU,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.ProcessCpu)
  })
_sym_db.RegisterMessage(ProcessCpu)

MemoryUsage = _reflection.GeneratedProtocolMessageType('MemoryUsage', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYUSAGE,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.MemoryUsage)
  })
_sym_db.RegisterMessage(MemoryUsage)

Memory = _reflection.GeneratedProtocolMessageType('Memory', (_message.Message,), {
  'DESCRIPTOR' : _MEMORY,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.Memory)
  })
_sym_db.RegisterMessage(Memory)

GarbageCollector = _reflection.GeneratedProtocolMessageType('GarbageCollector', (_message.Message,), {
  'DESCRIPTOR' : _GARBAGECOLLECTOR,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.GarbageCollector)
  })
_sym_db.RegisterMessage(GarbageCollector)

MemoryPool = _reflection.GeneratedProtocolMessageType('MemoryPool', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYPOOL,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.MemoryPool)
  })
_sym_db.RegisterMessage(MemoryPool)

Threads = _reflection.GeneratedProtocolMessageType('Threads', (_message.Message,), {
  'DESCRIPTOR' : _THREADS,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.Threads)
  })
_sym_db.RegisterMessage(Threads)

NodeCoreMetrics = _reflection.GeneratedProtocolMessageType('NodeCoreMetrics', (_message.Message,), {
  'DESCRIPTOR' : _NODECOREMETRICS,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.NodeCoreMetrics)
  })
_sym_db.RegisterMessage(NodeCoreMetrics)

GarbageCollectors = _reflection.GeneratedProtocolMessageType('GarbageCollectors', (_message.Message,), {
  'DESCRIPTOR' : _GARBAGECOLLECTORS,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.GarbageCollectors)
  })
_sym_db.RegisterMessage(GarbageCollectors)

MemoryPools = _reflection.GeneratedProtocolMessageType('MemoryPools', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYPOOLS,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.MemoryPools)
  })
_sym_db.RegisterMessage(MemoryPools)

Peers = _reflection.GeneratedProtocolMessageType('Peers', (_message.Message,), {
  'DESCRIPTOR' : _PEERS,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.Peers)
  })
_sym_db.RegisterMessage(Peers)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), {
  'DESCRIPTOR' : _PEER,
  '__module__' : 'diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.diagnostics.Peer)
  })
_sym_db.RegisterMessage(Peer)



_DIAGNOSTICS = _descriptor.ServiceDescriptor(
  name='Diagnostics',
  full_name='io.casperlabs.node.api.diagnostics.Diagnostics',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1496,
  serialized_end=2235,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPeers',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.ListPeers',
    index=0,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_PEERS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListDiscoveredPeers',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.ListDiscoveredPeers',
    index=1,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_PEERS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProcessCpu',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.GetProcessCpu',
    index=2,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_PROCESSCPU,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMemoryUsage',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.GetMemoryUsage',
    index=3,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_MEMORYUSAGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGarbageCollectors',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.GetGarbageCollectors',
    index=4,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_GARBAGECOLLECTORS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMemoryPools',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.GetMemoryPools',
    index=5,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_MEMORYPOOLS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetThreads',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.GetThreads',
    index=6,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_THREADS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNodeCoreMetrics',
    full_name='io.casperlabs.node.api.diagnostics.Diagnostics.GetNodeCoreMetrics',
    index=7,
    containing_service=None,
    input_type=empty__pb2._EMPTY,
    output_type=_NODECOREMETRICS,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DIAGNOSTICS)

DESCRIPTOR.services_by_name['Diagnostics'] = _DIAGNOSTICS

# @@protoc_insertion_point(module_scope)
