# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: casper.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import empty_pb2 as empty__pb2
from . import consensus_pb2 as consensus__pb2
from . import info_pb2 as info__pb2
from . import state_pb2 as state__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='casper.proto',
  package='io.casperlabs.node.api.casper',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0c\x63\x61sper.proto\x12\x1dio.casperlabs.node.api.casper\x1a\x11\x61nnotations.proto\x1a\x0b\x65mpty.proto\x1a\x0f\x63onsensus.proto\x1a\ninfo.proto\x1a\x0bstate.proto\"G\n\rDeployRequest\x12\x36\n\x06\x64\x65ploy\x18\x01 \x01(\x0b\x32&.io.casperlabs.casper.consensus.Deploy\"s\n\x13GetBlockInfoRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\x33.io.casperlabs.casper.consensus.info.BlockInfo.View\"}\n\x17StreamBlockInfosRequest\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\r\x12\x10\n\x08max_rank\x18\x02 \x01(\x04\x12\x41\n\x04view\x18\x03 \x01(\x0e\x32\x33.io.casperlabs.casper.consensus.info.BlockInfo.View\"v\n\x14GetDeployInfoRequest\x12\x1a\n\x12\x64\x65ploy_hash_base16\x18\x01 \x01(\t\x12\x42\n\x04view\x18\x02 \x01(\x0e\x32\x34.io.casperlabs.casper.consensus.info.DeployInfo.View\"z\n\x19StreamBlockDeploysRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12\x42\n\x04view\x18\x02 \x01(\x0e\x32\x34.io.casperlabs.casper.consensus.info.DeployInfo.View\"\xd9\x01\n\nStateQuery\x12I\n\x0bkey_variant\x18\x01 \x01(\x0e\x32\x34.io.casperlabs.node.api.casper.StateQuery.KeyVariant\x12\x12\n\nkey_base16\x18\x02 \x01(\t\x12\x15\n\rpath_segments\x18\x03 \x03(\t\"U\n\nKeyVariant\x12\x1b\n\x17KEY_VARIANT_UNSPECIFIED\x10\x00\x12\x08\n\x04HASH\x10\x01\x12\x08\n\x04UREF\x10\x02\x12\x0b\n\x07\x41\x44\x44RESS\x10\x03\x12\t\n\x05LOCAL\x10\x04\"k\n\x14GetBlockStateRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12\x38\n\x05query\x18\x02 \x01(\x0b\x32).io.casperlabs.node.api.casper.StateQuery\"r\n\x19\x42\x61tchGetBlockStateRequest\x12\x19\n\x11\x62lock_hash_base16\x18\x01 \x01(\t\x12:\n\x07queries\x18\x02 \x03(\x0b\x32).io.casperlabs.node.api.casper.StateQuery\"Y\n\x1a\x42\x61tchGetBlockStateResponse\x12;\n\x06values\x18\x01 \x03(\x0b\x32+.io.casperlabs.casper.consensus.state.Value2\xfb\x07\n\rCasperService\x12g\n\x06\x44\x65ploy\x12,.io.casperlabs.node.api.casper.DeployRequest\x1a\x16.google.protobuf.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x07\x64\x65ploys:\x06\x64\x65ploy\x12\x91\x01\n\x0cGetBlockInfo\x12\x32.io.casperlabs.node.api.casper.GetBlockInfoRequest\x1a..io.casperlabs.casper.consensus.info.BlockInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15{block_hash_base16=*}\x12\x8c\x01\n\x10StreamBlockInfos\x12\x36.io.casperlabs.node.api.casper.StreamBlockInfosRequest\x1a..io.casperlabs.casper.consensus.info.BlockInfo\"\x0e\x82\xd3\xe4\x93\x02\x08\x12\x06\x62locks0\x01\x12\x95\x01\n\rGetDeployInfo\x12\x33.io.casperlabs.node.api.casper.GetDeployInfoRequest\x1a/.io.casperlabs.casper.consensus.info.DeployInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16{deploy_hash_base16=*}\x12\x98\x01\n\x12StreamBlockDeploys\x12\x38.io.casperlabs.node.api.casper.StreamBlockDeploysRequest\x1a\x35.io.casperlabs.casper.consensus.Block.ProcessedDeploy\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07\x64\x65ploys0\x01\x12\x83\x01\n\rGetBlockState\x12\x33.io.casperlabs.node.api.casper.GetBlockStateRequest\x1a+.io.casperlabs.casper.consensus.state.Value\"\x10\x82\xd3\xe4\x93\x02\n\"\x05state:\x01*\x12\xa4\x01\n\x12\x42\x61tchGetBlockState\x12\x38.io.casperlabs.node.api.casper.BatchGetBlockStateRequest\x1a\x39.io.casperlabs.node.api.casper.BatchGetBlockStateResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0estate:batchGet:\x01*b\x06proto3')
  ,
  dependencies=[annotations__pb2.DESCRIPTOR,empty__pb2.DESCRIPTOR,consensus__pb2.DESCRIPTOR,info__pb2.DESCRIPTOR,state__pb2.DESCRIPTOR,])



_STATEQUERY_KEYVARIANT = _descriptor.EnumDescriptor(
  name='KeyVariant',
  full_name='io.casperlabs.node.api.casper.StateQuery.KeyVariant',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KEY_VARIANT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HASH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UREF', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=815,
  serialized_end=900,
)
_sym_db.RegisterEnumDescriptor(_STATEQUERY_KEYVARIANT)


_DEPLOYREQUEST = _descriptor.Descriptor(
  name='DeployRequest',
  full_name='io.casperlabs.node.api.casper.DeployRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy', full_name='io.casperlabs.node.api.casper.DeployRequest.deploy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=192,
)


_GETBLOCKINFOREQUEST = _descriptor.Descriptor(
  name='GetBlockInfoRequest',
  full_name='io.casperlabs.node.api.casper.GetBlockInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.GetBlockInfoRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.GetBlockInfoRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=309,
)


_STREAMBLOCKINFOSREQUEST = _descriptor.Descriptor(
  name='StreamBlockInfosRequest',
  full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest.depth', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_rank', full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest.max_rank', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.StreamBlockInfosRequest.view', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=436,
)


_GETDEPLOYINFOREQUEST = _descriptor.Descriptor(
  name='GetDeployInfoRequest',
  full_name='io.casperlabs.node.api.casper.GetDeployInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_hash_base16', full_name='io.casperlabs.node.api.casper.GetDeployInfoRequest.deploy_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.GetDeployInfoRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=556,
)


_STREAMBLOCKDEPLOYSREQUEST = _descriptor.Descriptor(
  name='StreamBlockDeploysRequest',
  full_name='io.casperlabs.node.api.casper.StreamBlockDeploysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.StreamBlockDeploysRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='io.casperlabs.node.api.casper.StreamBlockDeploysRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=680,
)


_STATEQUERY = _descriptor.Descriptor(
  name='StateQuery',
  full_name='io.casperlabs.node.api.casper.StateQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_variant', full_name='io.casperlabs.node.api.casper.StateQuery.key_variant', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_base16', full_name='io.casperlabs.node.api.casper.StateQuery.key_base16', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path_segments', full_name='io.casperlabs.node.api.casper.StateQuery.path_segments', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATEQUERY_KEYVARIANT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=900,
)


_GETBLOCKSTATEREQUEST = _descriptor.Descriptor(
  name='GetBlockStateRequest',
  full_name='io.casperlabs.node.api.casper.GetBlockStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.GetBlockStateRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query', full_name='io.casperlabs.node.api.casper.GetBlockStateRequest.query', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=1009,
)


_BATCHGETBLOCKSTATEREQUEST = _descriptor.Descriptor(
  name='BatchGetBlockStateRequest',
  full_name='io.casperlabs.node.api.casper.BatchGetBlockStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_hash_base16', full_name='io.casperlabs.node.api.casper.BatchGetBlockStateRequest.block_hash_base16', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queries', full_name='io.casperlabs.node.api.casper.BatchGetBlockStateRequest.queries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1125,
)


_BATCHGETBLOCKSTATERESPONSE = _descriptor.Descriptor(
  name='BatchGetBlockStateResponse',
  full_name='io.casperlabs.node.api.casper.BatchGetBlockStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.node.api.casper.BatchGetBlockStateResponse.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1216,
)

_DEPLOYREQUEST.fields_by_name['deploy'].message_type = consensus__pb2._DEPLOY
_GETBLOCKINFOREQUEST.fields_by_name['view'].enum_type = info__pb2._BLOCKINFO_VIEW
_STREAMBLOCKINFOSREQUEST.fields_by_name['view'].enum_type = info__pb2._BLOCKINFO_VIEW
_GETDEPLOYINFOREQUEST.fields_by_name['view'].enum_type = info__pb2._DEPLOYINFO_VIEW
_STREAMBLOCKDEPLOYSREQUEST.fields_by_name['view'].enum_type = info__pb2._DEPLOYINFO_VIEW
_STATEQUERY.fields_by_name['key_variant'].enum_type = _STATEQUERY_KEYVARIANT
_STATEQUERY_KEYVARIANT.containing_type = _STATEQUERY
_GETBLOCKSTATEREQUEST.fields_by_name['query'].message_type = _STATEQUERY
_BATCHGETBLOCKSTATEREQUEST.fields_by_name['queries'].message_type = _STATEQUERY
_BATCHGETBLOCKSTATERESPONSE.fields_by_name['values'].message_type = state__pb2._VALUE
DESCRIPTOR.message_types_by_name['DeployRequest'] = _DEPLOYREQUEST
DESCRIPTOR.message_types_by_name['GetBlockInfoRequest'] = _GETBLOCKINFOREQUEST
DESCRIPTOR.message_types_by_name['StreamBlockInfosRequest'] = _STREAMBLOCKINFOSREQUEST
DESCRIPTOR.message_types_by_name['GetDeployInfoRequest'] = _GETDEPLOYINFOREQUEST
DESCRIPTOR.message_types_by_name['StreamBlockDeploysRequest'] = _STREAMBLOCKDEPLOYSREQUEST
DESCRIPTOR.message_types_by_name['StateQuery'] = _STATEQUERY
DESCRIPTOR.message_types_by_name['GetBlockStateRequest'] = _GETBLOCKSTATEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetBlockStateRequest'] = _BATCHGETBLOCKSTATEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetBlockStateResponse'] = _BATCHGETBLOCKSTATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeployRequest = _reflection.GeneratedProtocolMessageType('DeployRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.DeployRequest)
  })
_sym_db.RegisterMessage(DeployRequest)

GetBlockInfoRequest = _reflection.GeneratedProtocolMessageType('GetBlockInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKINFOREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.GetBlockInfoRequest)
  })
_sym_db.RegisterMessage(GetBlockInfoRequest)

StreamBlockInfosRequest = _reflection.GeneratedProtocolMessageType('StreamBlockInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOCKINFOSREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StreamBlockInfosRequest)
  })
_sym_db.RegisterMessage(StreamBlockInfosRequest)

GetDeployInfoRequest = _reflection.GeneratedProtocolMessageType('GetDeployInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYINFOREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.GetDeployInfoRequest)
  })
_sym_db.RegisterMessage(GetDeployInfoRequest)

StreamBlockDeploysRequest = _reflection.GeneratedProtocolMessageType('StreamBlockDeploysRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOCKDEPLOYSREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StreamBlockDeploysRequest)
  })
_sym_db.RegisterMessage(StreamBlockDeploysRequest)

StateQuery = _reflection.GeneratedProtocolMessageType('StateQuery', (_message.Message,), {
  'DESCRIPTOR' : _STATEQUERY,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.StateQuery)
  })
_sym_db.RegisterMessage(StateQuery)

GetBlockStateRequest = _reflection.GeneratedProtocolMessageType('GetBlockStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKSTATEREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.GetBlockStateRequest)
  })
_sym_db.RegisterMessage(GetBlockStateRequest)

BatchGetBlockStateRequest = _reflection.GeneratedProtocolMessageType('BatchGetBlockStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETBLOCKSTATEREQUEST,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.BatchGetBlockStateRequest)
  })
_sym_db.RegisterMessage(BatchGetBlockStateRequest)

BatchGetBlockStateResponse = _reflection.GeneratedProtocolMessageType('BatchGetBlockStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETBLOCKSTATERESPONSE,
  '__module__' : 'casper_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.node.api.casper.BatchGetBlockStateResponse)
  })
_sym_db.RegisterMessage(BatchGetBlockStateResponse)



_CASPERSERVICE = _descriptor.ServiceDescriptor(
  name='CasperService',
  full_name='io.casperlabs.node.api.casper.CasperService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1219,
  serialized_end=2238,
  methods=[
  _descriptor.MethodDescriptor(
    name='Deploy',
    full_name='io.casperlabs.node.api.casper.CasperService.Deploy',
    index=0,
    containing_service=None,
    input_type=_DEPLOYREQUEST,
    output_type=empty__pb2._EMPTY,
    serialized_options=_b('\202\323\344\223\002\021\"\007deploys:\006deploy'),
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockInfo',
    full_name='io.casperlabs.node.api.casper.CasperService.GetBlockInfo',
    index=1,
    containing_service=None,
    input_type=_GETBLOCKINFOREQUEST,
    output_type=info__pb2._BLOCKINFO,
    serialized_options=_b('\202\323\344\223\002\027\022\025{block_hash_base16=*}'),
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlockInfos',
    full_name='io.casperlabs.node.api.casper.CasperService.StreamBlockInfos',
    index=2,
    containing_service=None,
    input_type=_STREAMBLOCKINFOSREQUEST,
    output_type=info__pb2._BLOCKINFO,
    serialized_options=_b('\202\323\344\223\002\010\022\006blocks'),
  ),
  _descriptor.MethodDescriptor(
    name='GetDeployInfo',
    full_name='io.casperlabs.node.api.casper.CasperService.GetDeployInfo',
    index=3,
    containing_service=None,
    input_type=_GETDEPLOYINFOREQUEST,
    output_type=info__pb2._DEPLOYINFO,
    serialized_options=_b('\202\323\344\223\002\030\022\026{deploy_hash_base16=*}'),
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlockDeploys',
    full_name='io.casperlabs.node.api.casper.CasperService.StreamBlockDeploys',
    index=4,
    containing_service=None,
    input_type=_STREAMBLOCKDEPLOYSREQUEST,
    output_type=consensus__pb2._BLOCK_PROCESSEDDEPLOY,
    serialized_options=_b('\202\323\344\223\002\t\022\007deploys'),
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockState',
    full_name='io.casperlabs.node.api.casper.CasperService.GetBlockState',
    index=5,
    containing_service=None,
    input_type=_GETBLOCKSTATEREQUEST,
    output_type=state__pb2._VALUE,
    serialized_options=_b('\202\323\344\223\002\n\"\005state:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetBlockState',
    full_name='io.casperlabs.node.api.casper.CasperService.BatchGetBlockState',
    index=6,
    containing_service=None,
    input_type=_BATCHGETBLOCKSTATEREQUEST,
    output_type=_BATCHGETBLOCKSTATERESPONSE,
    serialized_options=_b('\202\323\344\223\002\023\"\016state:batchGet:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CASPERSERVICE)

DESCRIPTOR.services_by_name['CasperService'] = _CASPERSERVICE

# @@protoc_insertion_point(module_scope)
